@@ -178,6 +178,44 @@ static gboolean remmina_pref_file_do_copy(const char *src_path, const char *dst_
 	return ok;
 }
 
+void remmina_pref_file_load_colors(GKeyFile *gkeyfile, RemminaColorPref *color_pref)
+{
+	const struct {
+		const char *name;
+		char **setting;
+		char *fallback;
+	} colors[] = {
+		{ "background", &color_pref->background, "#d5ccba" },
+		{ "cursor",     &color_pref->cursor,     "#45373c" },
+		{ "foreground", &color_pref->foreground, "#45373c" },
+		{ "color0",     &color_pref->color0,     "#20111b" },
+		{ "color1",     &color_pref->color1,     "#be100e" },
+		{ "color2",     &color_pref->color2,     "#858162" },
+		{ "color3",     &color_pref->color3,     "#eaa549" },
+		{ "color4",     &color_pref->color4,     "#426a79" },
+		{ "color5",     &color_pref->color5,     "#97522c" },
+		{ "color6",     &color_pref->color6,     "#989a9c" },
+		{ "color7",     &color_pref->color7,     "#968c83" },
+		{ "color8",     &color_pref->color8,     "#5e5252" },
+		{ "color9",     &color_pref->color9,     "#be100e" },
+		{ "color10",    &color_pref->color10,    "#858162" },
+		{ "color11",    &color_pref->color11,    "#eaa549" },
+		{ "color12",    &color_pref->color12,    "#426a79" },
+		{ "color13",    &color_pref->color13,    "#97522c" },
+		{ "color14",    &color_pref->color14,    "#989a9c" },
+		{ "color15",    &color_pref->color15,    "#d5ccba" },
+	};
+
+	int i;
+	for (i = 0; i < (sizeof(colors) / sizeof(colors[0])); i++) {
+		if (g_key_file_has_key(gkeyfile, "ssh_colors", colors[i].name, NULL))
+			*colors[i].setting = g_key_file_get_string(gkeyfile, "ssh_colors", colors[i].name,
+				NULL);
+		else
+			*colors[i].setting = colors[i].fallback;
+	}
+}
+
 void remmina_pref_init(void)
 {
 	TRACE_CALL(__func__);
@@ -578,119 +616,7 @@ void remmina_pref_init(void)
 		g_remove(remmina_colors_file);
 	}
 
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "background", NULL))
-		remmina_pref.background = g_key_file_get_string(gkeyfile, "ssh_colors", "background",
-			NULL);
-	else
-		remmina_pref.background = "#d5ccba";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "cursor", NULL))
-		remmina_pref.cursor = g_key_file_get_string(gkeyfile, "ssh_colors", "cursor",
-			NULL);
-	else
-		remmina_pref.cursor = "#45373c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "foreground", NULL))
-		remmina_pref.foreground = g_key_file_get_string(gkeyfile, "ssh_colors", "foreground",
-			NULL);
-	else
-		remmina_pref.foreground = "#45373c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color0", NULL))
-		remmina_pref.color0 = g_key_file_get_string(gkeyfile, "ssh_colors", "color0",
-			NULL);
-	else
-		remmina_pref.color0 = "#20111b";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color1", NULL))
-		remmina_pref.color1 = g_key_file_get_string(gkeyfile, "ssh_colors", "color1",
-			NULL);
-	else
-		remmina_pref.color1 = "#be100e";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color2", NULL))
-		remmina_pref.color2 = g_key_file_get_string(gkeyfile, "ssh_colors", "color2",
-			NULL);
-	else
-		remmina_pref.color2 = "#858162";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color3", NULL))
-		remmina_pref.color3 = g_key_file_get_string(gkeyfile, "ssh_colors", "color3",
-			NULL);
-	else
-		remmina_pref.color3 = "#eaa549";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color4", NULL))
-		remmina_pref.color4 = g_key_file_get_string(gkeyfile, "ssh_colors", "color4",
-			NULL);
-	else
-		remmina_pref.color4 = "#426a79";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color5", NULL))
-		remmina_pref.color5 = g_key_file_get_string(gkeyfile, "ssh_colors", "color5",
-			NULL);
-	else
-		remmina_pref.color5 = "#97522c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color6", NULL))
-		remmina_pref.color6 = g_key_file_get_string(gkeyfile, "ssh_colors", "color6",
-			NULL);
-	else
-		remmina_pref.color6 = "#989a9c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color7", NULL))
-		remmina_pref.color7 = g_key_file_get_string(gkeyfile, "ssh_colors", "color7",
-			NULL);
-	else
-		remmina_pref.color7 = "#968c83";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color8", NULL))
-		remmina_pref.color8 = g_key_file_get_string(gkeyfile, "ssh_colors", "color8",
-			NULL);
-	else
-		remmina_pref.color8 = "#5e5252";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color9", NULL))
-		remmina_pref.color9 = g_key_file_get_string(gkeyfile, "ssh_colors", "color9",
-			NULL);
-	else
-		remmina_pref.color9 = "#be100e";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color10", NULL))
-		remmina_pref.color10 = g_key_file_get_string(gkeyfile, "ssh_colors", "color10",
-			NULL);
-	else
-		remmina_pref.color10 = "#858162";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color11", NULL))
-		remmina_pref.color11 = g_key_file_get_string(gkeyfile, "ssh_colors", "color11",
-			NULL);
-	else
-		remmina_pref.color11 = "#eaa549";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color12", NULL))
-		remmina_pref.color12 = g_key_file_get_string(gkeyfile, "ssh_colors", "color12",
-			NULL);
-	else
-		remmina_pref.color12 = "#426a79";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color13", NULL))
-		remmina_pref.color13 = g_key_file_get_string(gkeyfile, "ssh_colors", "color13",
-			NULL);
-	else
-		remmina_pref.color13 = "#97522c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color14", NULL))
-		remmina_pref.color14 = g_key_file_get_string(gkeyfile, "ssh_colors", "color14",
-			NULL);
-	else
-		remmina_pref.color14 = "#989a9c";
-
-	if (g_key_file_has_key(gkeyfile, "ssh_colors", "color15", NULL))
-		remmina_pref.color15 = g_key_file_get_string(gkeyfile, "ssh_colors", "color15",
-			NULL);
-	else
-		remmina_pref.color15 = "#d5ccba";
+	remmina_pref_file_load_colors(gkeyfile, &remmina_pref.color_pref);
 
 	if (g_key_file_has_key(gkeyfile, "usage_stats", "periodic_usage_stats_permission_asked", NULL))
 		remmina_pref.periodic_usage_stats_permission_asked = g_key_file_get_boolean(gkeyfile, "usage_stats", "periodic_usage_stats_permission_asked", NULL);
@@ -721,10 +647,11 @@ void remmina_pref_init(void)
 	remmina_pref_init_keymap();
 }
 
-void remmina_pref_save(void)
+gboolean remmina_pref_save(void)
 {
 	TRACE_CALL(__func__);
 	GKeyFile *gkeyfile;
+	GError *error = NULL;
 	gchar *content;
 	gsize length;
 
@@ -789,25 +716,25 @@ void remmina_pref_save(void)
 	g_key_file_set_string(gkeyfile, "remmina_pref", "vte_font", remmina_pref.vte_font ? remmina_pref.vte_font : "");
 	g_key_file_set_boolean(gkeyfile, "remmina_pref", "vte_allow_bold_text", remmina_pref.vte_allow_bold_text);
 	g_key_file_set_integer(gkeyfile, "remmina_pref", "vte_lines", remmina_pref.vte_lines);
-	g_key_file_set_string(gkeyfile, "ssh_colors", "background", remmina_pref.background ? remmina_pref.background : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "cursor", remmina_pref.cursor ? remmina_pref.cursor : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "foreground", remmina_pref.foreground ? remmina_pref.foreground : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color0", remmina_pref.color0 ? remmina_pref.color0 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color1", remmina_pref.color1 ? remmina_pref.color1 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color2", remmina_pref.color2 ? remmina_pref.color2 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color3", remmina_pref.color3 ? remmina_pref.color3 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color4", remmina_pref.color4 ? remmina_pref.color4 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color5", remmina_pref.color5 ? remmina_pref.color5 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color6", remmina_pref.color6 ? remmina_pref.color6 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color7", remmina_pref.color7 ? remmina_pref.color7 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color8", remmina_pref.color8 ? remmina_pref.color8 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color9", remmina_pref.color9 ? remmina_pref.color9 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color10", remmina_pref.color10 ? remmina_pref.color10 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color11", remmina_pref.color11 ? remmina_pref.color11 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color12", remmina_pref.color12 ? remmina_pref.color12 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color13", remmina_pref.color13 ? remmina_pref.color13 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color14", remmina_pref.color14 ? remmina_pref.color14 : "");
-	g_key_file_set_string(gkeyfile, "ssh_colors", "color15", remmina_pref.color15 ? remmina_pref.color15 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "background", remmina_pref.color_pref.background ? remmina_pref.color_pref.background : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "cursor", remmina_pref.color_pref.cursor ? remmina_pref.color_pref.cursor : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "foreground", remmina_pref.color_pref.foreground ? remmina_pref.color_pref.foreground : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color0", remmina_pref.color_pref.color0 ? remmina_pref.color_pref.color0 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color1", remmina_pref.color_pref.color1 ? remmina_pref.color_pref.color1 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color2", remmina_pref.color_pref.color2 ? remmina_pref.color_pref.color2 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color3", remmina_pref.color_pref.color3 ? remmina_pref.color_pref.color3 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color4", remmina_pref.color_pref.color4 ? remmina_pref.color_pref.color4 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color5", remmina_pref.color_pref.color5 ? remmina_pref.color_pref.color5 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color6", remmina_pref.color_pref.color6 ? remmina_pref.color_pref.color6 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color7", remmina_pref.color_pref.color7 ? remmina_pref.color_pref.color7 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color8", remmina_pref.color_pref.color8 ? remmina_pref.color_pref.color8 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color9", remmina_pref.color_pref.color9 ? remmina_pref.color_pref.color9 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color10", remmina_pref.color_pref.color10 ? remmina_pref.color_pref.color10 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color11", remmina_pref.color_pref.color11 ? remmina_pref.color_pref.color11 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color12", remmina_pref.color_pref.color12 ? remmina_pref.color_pref.color12 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color13", remmina_pref.color_pref.color13 ? remmina_pref.color_pref.color13 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color14", remmina_pref.color_pref.color14 ? remmina_pref.color_pref.color14 : "");
+	g_key_file_set_string(gkeyfile, "ssh_colors", "color15", remmina_pref.color_pref.color15 ? remmina_pref.color_pref.color15 : "");
 
 	g_key_file_set_boolean(gkeyfile, "usage_stats", "periodic_usage_stats_permission_asked", remmina_pref.periodic_usage_stats_permission_asked);
 	g_key_file_set_boolean(gkeyfile, "usage_stats", "periodic_usage_stats_permitted", remmina_pref.periodic_usage_stats_permitted);
@@ -816,10 +743,19 @@ void remmina_pref_save(void)
 			remmina_pref.periodic_usage_stats_uuid_prefix ? remmina_pref.periodic_usage_stats_uuid_prefix : "");
 
 	content = g_key_file_to_data(gkeyfile, &length, NULL);
-	g_file_set_contents(remmina_pref_file, content, length, NULL);
+	g_file_set_contents(remmina_pref_file, content, length, &error);
 
+	if (error != NULL)
+	{
+		g_print ("%s\n", error->message);
+		g_clear_error (&error);
+		g_key_file_free(gkeyfile);
+		g_free(content);
+		return FALSE;
+	}
 	g_key_file_free(gkeyfile);
 	g_free(content);
+	return TRUE;
 }
 
 void remmina_pref_add_recent(const gchar *protocol, const gchar *server)
